@@ -30,18 +30,7 @@
 //! Replace `TurtleParser` by `NTriplesParser`, `NQuadsParser` or `TriGParser` to read an N-Triples, N-Quads or TriG file instead.
 //!
 //! `NTriplesParser` and `NQuadsParser` do not use the second argument of the `new` function that is the IRI of the file.
-//!
-//! [Sophia](https://crates.io/crates/sophia_api) adapters for Rio parsers are provided if the `sophia` feature is enabled.
-#![deny(
-    future_incompatible,
-    nonstandard_style,
-    rust_2018_idioms,
-    missing_copy_implementations,
-    trivial_casts,
-    trivial_numeric_casts,
-    unsafe_code,
-    unused_qualifications
-)]
+#![deny(unsafe_code)]
 #![doc(test(attr(deny(warnings))))]
 
 mod error;
@@ -68,8 +57,8 @@ pub use turtle::TurtleParser;
 #[cfg(feature = "generalized")]
 pub use gtrig::GTriGParser;
 
-#[cfg(feature = "sophia_api")]
-mod sophia;
-
 /// Maximal number of nested structures (collections, blank node, quoted triples...).
+///
+/// This limit is set in order to avoid stack overflow error when parsing such structures due to too many recursive calls.
+/// The actual limit value is a wet finger compromise between not failing to parse valid files and avoiding to trigger stack overflow errors.
 const MAX_STACK_SIZE: usize = 128;
